@@ -66,15 +66,15 @@ FrMimeTypeDescription mime_type_desc[] = {
 	{ "application/x-ar",                   ".a",        N_("Ar (.a)"), 0 },
 	{ "application/x-ar",                   ".ar",       N_("Ar (.ar)"), 0 },
 	{ "application/x-arj",                  ".arj",      N_("Arj (.arj)"), 0 },
-	{ "application/x-bzip",                 ".bz2",      NULL, 0 },
-	{ "application/x-bzip-compressed-tar",  ".tar.bz2",  N_("Tar compressed with bzip2 (.tar.bz2)"), 0 },
+	{ "application/x-bzip2",                ".bz2",      NULL, 0 },
+	{ "application/x-bzip2-compressed-tar", ".tar.bz2",  N_("Tar compressed with bzip2 (.tar.bz2)"), 0 },
 	{ "application/x-bzip1",                ".bz",       NULL, 0 },
 	{ "application/x-bzip1-compressed-tar", ".tar.bz",   N_("Tar compressed with bzip (.tar.bz)"), 0 },
 	{ "application/vnd.ms-cab-compressed",  ".cab",      N_("Cabinet (.cab)"), 0 },
 	{ "application/x-cbr",                  ".cbr",      N_("Rar Archived Comic Book (.cbr)"), 0 },
 	{ "application/x-cbz",                  ".cbz",      N_("Zip Archived Comic Book (.cbz)"), 0 },
-	{ "application/x-cd-image",             ".iso",      NULL, 0 },
-	{ "application/x-raw-disk-image",       ".img",      NULL, 0 },
+	{ "application/vnd.efi.iso",             ".iso",     NULL, 0 },
+	{ "application/vnd.efi.img",            ".img",      NULL, 0 },
 	{ "application/x-compress",             ".Z",        NULL, 0 },
 	{ "application/x-compressed-tar",       ".tar.gz",   N_("Tar compressed with gzip (.tar.gz)"), 0 },
 	{ "application/x-cpio",                 ".cpio",     NULL, 0 },
@@ -119,8 +119,7 @@ FrExtensionType file_ext_type[] = {
 	{ ".ar", "application/x-ar" },
 	{ ".arj", "application/x-arj" },
 	{ ".bin", "application/x-stuffit" },
-	{ ".bz", "application/x-bzip" },
-	{ ".bz2", "application/x-bzip" },
+	{ ".bz2", "application/x-bzip2" },
 	{ ".cab", "application/vnd.ms-cab-compressed" },
 	{ ".cbr", "application/x-cbr" },
 	{ ".cbz", "application/x-cbz" },
@@ -130,7 +129,8 @@ FrExtensionType file_ext_type[] = {
 	{ ".exe", "application/x-ms-dos-executable" },
 	{ ".gz", "application/gzip" },
 	{ ".iso", "application/x-cd-image" },
-	{ ".img", "application/x-raw-disk-image" },
+	{ ".iso", "application/vnd.efi.iso" },
+	{ ".img", "application/vnd.efi.img" },
 	{ ".jar", "application/x-java-archive" },
 	{ ".lha", "application/x-lha" },
 	{ ".lrz", "application/x-lrzip" },
@@ -144,8 +144,7 @@ FrExtensionType file_ext_type[] = {
 	{ ".sit", "application/x-stuffit" },
 	{ ".swm", "application/x-ms-wim" },
 	{ ".tar", "application/x-tar" },
-	{ ".tar.bz", "application/x-bzip-compressed-tar" },
-	{ ".tar.bz2", "application/x-bzip-compressed-tar" },
+	{ ".tar.bz2", "application/x-bzip2-compressed-tar" },
 	{ ".tar.gz", "application/x-compressed-tar" },
 	{ ".tar.lrz", "application/x-lrzip-compressed-tar" },
 	{ ".tar.lz", "application/x-lzip-compressed-tar" },
@@ -156,8 +155,7 @@ FrExtensionType file_ext_type[] = {
 	{ ".tar.Z", "application/x-tarz" },
 	{ ".tar.zst", "application/x-zstd-compressed-tar" },
 	{ ".taz", "application/x-tarz" },
-	{ ".tbz", "application/x-bzip-compressed-tar" },
-	{ ".tbz2", "application/x-bzip-compressed-tar" },
+	{ ".tbz2", "application/x-bzip2-compressed-tar" },
 	{ ".tgz", "application/x-compressed-tar" },
 	{ ".txz", "application/x-xz-compressed-tar" },
 	{ ".tzst", "application/x-zstd-compressed-tar" },
