@@ -21,6 +21,7 @@
 #include <QDateTime>
 #include <QProgressBar>
 #include <QLabel>
+#include <QLocale>
 #include <QTextCodec>
 #include <QActionGroup>
 #include <QLineEdit>
@@ -79,6 +80,14 @@ MainWindow::MainWindow(QWidget* parent):
     viewModeGroup->addAction(ui_->actionDirTreeMode);
     viewModeGroup->addAction(ui_->actionFlatListMode);
 
+    // icons are set here for having fallbacks
+    ui_->actionExtract->setIcon(QIcon::fromTheme(QStringLiteral("archive-extract"),
+                                                 QIcon::fromTheme(QStringLiteral("go-up"))));
+    ui_->actionAddFiles->setIcon(QIcon::fromTheme(QStringLiteral("archive-insert"),
+                                                  QIcon::fromTheme(QStringLiteral("insert-object"))));
+    ui_->actionAddFolder->setIcon(QIcon::fromTheme(QStringLiteral("archive-insert-directory"),
+                                                   QIcon::fromTheme(QStringLiteral("insert-object"))));
+
     // views icon size
     auto viewsIconSizeGroup = new QActionGroup{this};
     ui_->action16px->setData(16);
@@ -1039,7 +1048,7 @@ QList<QStandardItem *> MainWindow::createFileListRow(const ArchiverItem *file) {
     sizeItem->setData(QStringLiteral("size"), ArchiverItemRole);
     sizeItem->setEditable(false);
 
-    auto mtimeItem = new QStandardItem{mtime.toString(Qt::SystemLocaleShortDate)};
+    auto mtimeItem = new QStandardItem(QLocale::system().toString(mtime, QLocale::ShortFormat));
     mtimeItem->setData(QStringLiteral("mTime"), ArchiverItemRole);
     mtimeItem->setEditable(false);
 
