@@ -236,7 +236,7 @@ Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA  02110-1301, USA.<
         <location filename="../mainwindow.ui" line="14"/>
         <location filename="../mainwindow.cpp" line="323"/>
         <source>File Archiver</source>
-        <translation>파일 압춗 프로그램</translation>
+        <translation>파일 압축 프로그램</translation>
     </message>
     <message>
         <location filename="../mainwindow.ui" line="62"/>
